Liferay.Loader.define('segments-web$lodash@4.17.21/pickBy', ['module', 'exports', 'require', './_arrayMap', './_baseIteratee', './_basePickBy', './_getAllKeysIn'], function (module, exports, require) {
  var define = undefined;
  var arrayMap = require('./_arrayMap'),
      baseIteratee = require('./_baseIteratee'),
      basePickBy = require('./_basePickBy'),
      getAllKeysIn = require('./_getAllKeysIn');

  /**
   * Creates an object composed of the `object` properties `predicate` returns
   * truthy for. The predicate is invoked with two arguments: (value, key).
   *
   * @static
   * @memberOf _
   * @since 4.0.0
   * @category Object
   * @param {Object} object The source object.
   * @param {Function} [predicate=_.identity] The function invoked per property.
   * @returns {Object} Returns the new object.
   * @example
   *
   * var object = { 'a': 1, 'b': '2', 'c': 3 };
   *
   * _.pickBy(object, _.isNumber);
   * // => { 'a': 1, 'c': 3 }
   */
  function pickBy(object, predicate) {
    if (object == null) {
      return {};
    }
    var props = arrayMap(getAllKeysIn(object), function (prop) {
      return [prop];
    });
    predicate = baseIteratee(predicate);
    return basePickBy(object, props, function (value, path) {
      return predicate(value, path[0]);
    });
  }

  module.exports = pickBy;
});
//# sourceMappingURL=pickBy.js.map