Liferay.Loader.define('segments-web$lodash@4.17.21/trim', ['module', 'exports', 'require', './_baseToString', './_baseTrim', './_castSlice', './_charsEndIndex', './_charsStartIndex', './_stringToArray', './toString'], function (module, exports, require) {
  var define = undefined;
  var baseToString = require('./_baseToString'),
      baseTrim = require('./_baseTrim'),
      castSlice = require('./_castSlice'),
      charsEndIndex = require('./_charsEndIndex'),
      charsStartIndex = require('./_charsStartIndex'),
      stringToArray = require('./_stringToArray'),
      toString = require('./toString');

  /**
   * Removes leading and trailing whitespace or specified characters from `string`.
   *
   * @static
   * @memberOf _
   * @since 3.0.0
   * @category String
   * @param {string} [string=''] The string to trim.
   * @param {string} [chars=whitespace] The characters to trim.
   * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
   * @returns {string} Returns the trimmed string.
   * @example
   *
   * _.trim('  abc  ');
   * // => 'abc'
   *
   * _.trim('-_-abc-_-', '_-');
   * // => 'abc'
   *
   * _.map(['  foo  ', '  bar  '], _.trim);
   * // => ['foo', 'bar']
   */
  function trim(string, chars, guard) {
    string = toString(string);
    if (string && (guard || chars === undefined)) {
      return baseTrim(string);
    }
    if (!string || !(chars = baseToString(chars))) {
      return string;
    }
    var strSymbols = stringToArray(string),
        chrSymbols = stringToArray(chars),
        start = charsStartIndex(strSymbols, chrSymbols),
        end = charsEndIndex(strSymbols, chrSymbols) + 1;

    return castSlice(strSymbols, start, end).join('');
  }

  module.exports = trim;
});
//# sourceMappingURL=trim.js.map