Liferay.Loader.define('segments-web$lodash@4.17.21/unionWith', ['module', 'exports', 'require', './_baseFlatten', './_baseRest', './_baseUniq', './isArrayLikeObject', './last'], function (module, exports, require) {
  var define = undefined;
  var baseFlatten = require('./_baseFlatten'),
      baseRest = require('./_baseRest'),
      baseUniq = require('./_baseUniq'),
      isArrayLikeObject = require('./isArrayLikeObject'),
      last = require('./last');

  /**
   * This method is like `_.union` except that it accepts `comparator` which
   * is invoked to compare elements of `arrays`. Result values are chosen from
   * the first array in which the value occurs. The comparator is invoked
   * with two arguments: (arrVal, othVal).
   *
   * @static
   * @memberOf _
   * @since 4.0.0
   * @category Array
   * @param {...Array} [arrays] The arrays to inspect.
   * @param {Function} [comparator] The comparator invoked per element.
   * @returns {Array} Returns the new array of combined values.
   * @example
   *
   * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
   * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
   *
   * _.unionWith(objects, others, _.isEqual);
   * // => [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
   */
  var unionWith = baseRest(function (arrays) {
    var comparator = last(arrays);
    comparator = typeof comparator == 'function' ? comparator : undefined;
    return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true), undefined, comparator);
  });

  module.exports = unionWith;
});
//# sourceMappingURL=unionWith.js.map