Liferay.Loader.define('segments-web$lodash@4.17.21/xorBy', ['module', 'exports', 'require', './_arrayFilter', './_baseIteratee', './_baseRest', './_baseXor', './isArrayLikeObject', './last'], function (module, exports, require) {
  var define = undefined;
  var arrayFilter = require('./_arrayFilter'),
      baseIteratee = require('./_baseIteratee'),
      baseRest = require('./_baseRest'),
      baseXor = require('./_baseXor'),
      isArrayLikeObject = require('./isArrayLikeObject'),
      last = require('./last');

  /**
   * This method is like `_.xor` except that it accepts `iteratee` which is
   * invoked for each element of each `arrays` to generate the criterion by
   * which by which they're compared. The order of result values is determined
   * by the order they occur in the arrays. The iteratee is invoked with one
   * argument: (value).
   *
   * @static
   * @memberOf _
   * @since 4.0.0
   * @category Array
   * @param {...Array} [arrays] The arrays to inspect.
   * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
   * @returns {Array} Returns the new array of filtered values.
   * @example
   *
   * _.xorBy([2.1, 1.2], [2.3, 3.4], Math.floor);
   * // => [1.2, 3.4]
   *
   * // The `_.property` iteratee shorthand.
   * _.xorBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
   * // => [{ 'x': 2 }]
   */
  var xorBy = baseRest(function (arrays) {
    var iteratee = last(arrays);
    if (isArrayLikeObject(iteratee)) {
      iteratee = undefined;
    }
    return baseXor(arrayFilter(arrays, isArrayLikeObject), baseIteratee(iteratee, 2));
  });

  module.exports = xorBy;
});
//# sourceMappingURL=xorBy.js.map